@@ -10,7 +10,6 @@ from pykechain.defaults import ASYNC_REFRESH_INTERVAL, ASYNC_TIMEOUT_LIMIT, API_
 from pykechain.enums import ActivityType, ActivityStatus, Category, ActivityClassification, ActivityRootNames, \
     PaperSize, PaperOrientation
 from pykechain.exceptions import NotFoundError, IllegalArgumentError, APIError, MultipleFoundError
-from pykechain.models.activity2 import Activity2
 from pykechain.models.input_checks import check_datetime, check_text, check_list_of_text, check_enum, check_user, \
     check_type, check_base
 from pykechain.models.representations.component import RepresentationsComponent
@@ -21,7 +20,7 @@ from pykechain.models.widgets.widgets_manager import WidgetsManager
 from pykechain.utils import parse_datetime, is_valid_email, empty, Empty, clean_empty_values
 
 
-class Activity(TreeObject, TagsMixin, Activity2):
+class Activity(TreeObject, TagsMixin):
     """A virtual object representing a KE-chain activity.
 
     .. versionadded:: 2.0
@@ -50,23 +49,23 @@ class Activity(TreeObject, TagsMixin, Activity2):
 
         self._scope_id = json.get('scope_id')
 
-        self.ref = json.get('ref')  # type: Text
-        self.description = json.get('description', '')  # type: Text
-        self.status = json.get('status')  # type: ActivityStatus
-        self.classification = json.get('classification')  # type: ActivityClassification
-        self.activity_type = json.get('activity_type')  # type: ActivityType
+        self.ref: Text = json.get('ref')
+        self.description: Text = json.get('description', '')
+        self.status: ActivityStatus = json.get('status')
+        self.classification: ActivityClassification = json.get('classification')
+        self.activity_type: ActivityType = json.get('activity_type')
         self.start_date = parse_datetime(json.get('start_date'))
         self.due_date = parse_datetime(json.get('due_date'))
-        self.assignees_ids = json.get('assignees_ids', [])  # type: List[Text]
+        self.assignees_ids: List[Text] = json.get('assignees_ids', [])
         self._options = json.get('activity_options', {})
 
-        self._tags = json.get('tags', [])  # type: List[Text]
+        self._tags: List[Text] = json.get('tags', [])
         self._representations_container = RepresentationsComponent(
             self,
             self._options.get('representations', {}),
             self._save_representations,
         )
-        self._widgets_manager = None  # type: Optional[WidgetsManager]
+        self._widgets_manager: Optional[WidgetsManager] = None
 
     def __call__(self, *args, **kwargs) -> 'Activity':
         """Short-hand version of the `child` method."""
@@ -422,10 +421,10 @@ class Activity(TreeObject, TagsMixin, Activity2):
         return super().count_children(method="activities", **kwargs)
 
     def clone(
-        self,
-        parent: Optional[Union['Activity', Text]] = None,
-        update_dict: Optional[Dict] = None,
-        **kwargs
+            self,
+            parent: Optional[Union['Activity', Text]] = None,
+            update_dict: Optional[Dict] = None,
+            **kwargs
     ) -> Optional['Activity']:
         """
         Create a copy of this activity.
@@ -567,10 +566,8 @@ class Activity(TreeObject, TagsMixin, Activity2):
         -------
         >>> from datetime import datetime
         >>> my_task = project.activity('Specify the wheel diameter')
-        >>> my_task.edit(name='Specify wheel diameter and circumference',
-        ...              description='The diameter and circumference are specified in inches',
-        ...              start_date=datetime.utcnow(),  # naive time is interpreted as UTC time
-        ...              assignee='testuser')
+        >>> my_task.edit(name='Specify wheel diameter and circumference',description='The diameter and circumference'
+        ... 'are specified in inches', start_date=datetime.utcnow(), assignee='testuser')
 
         If we want to provide timezone aware datetime objects we can use the 3rd party convenience library :mod:`pytz`.
         Mind that we need to fetch the timezone first and use `<timezone>.localize(<your datetime>)` to make it
@@ -586,7 +583,7 @@ class Activity(TreeObject, TagsMixin, Activity2):
         >>> start_date_tzaware = datetime.now(pytz.utc)
         >>> mytimezone = pytz.timezone('Europe/Amsterdam')
         >>> due_date_tzaware = mytimezone.localize(datetime(2019, 10, 27, 23, 59, 0))
-        >>> my_task.edit(due_date=due_date_tzaware, start_date=start_date_tzaware)
+        >>> my_task.edit(start_date=start_date_tzaware,due_date=due_date_tzaware)
 
         Not mentioning an input parameter in the function will leave it unchanged. Setting a parameter as None will
         clear its value (where that is possible). The example below will clear the due_date, but leave everything else
@@ -914,7 +911,12 @@ class Activity(TreeObject, TagsMixin, Activity2):
         """
         return self._client.move_activity(self, parent, classification=classification)
 
-    def share_link(self, subject: Text, message: Text, recipient_users: List[Union[User, Text]]) -> None:
+    def share_link(
+            self,
+            subject: Text,
+            message: Text,
+            recipient_users: List[Union[User, Text]],
+            from_user: Optional[User] = None) -> None:
         """
         Share the link of the `Activity` through email.
 
@@ -924,6 +926,8 @@ class Activity(TreeObject, TagsMixin, Activity2):
         :type message: basestring
         :param recipient_users: users that will receive the email
         :type recipient_users: list(Union(User, Id))
+        :param from_user: User that shared the link (optional)
+        :type from_user: User object
         :raises APIError: if an internal server error occurred.
         """
         params = dict(
@@ -933,6 +937,12 @@ class Activity(TreeObject, TagsMixin, Activity2):
             activity_id=self.id
         )
 
+        if from_user:
+            check_user(from_user, User, 'from_user')
+            params.update(
+                from_user=from_user.id
+            )
+
         url = self._client._build_url('notification_share_activity_link')
 
         response = self._client._request('POST', url, data=params)
@@ -947,8 +957,10 @@ class Activity(TreeObject, TagsMixin, Activity2):
             recipient_users: List[Union[User, Text]],
             paper_size: Optional[PaperSize] = PaperSize.A3,
             paper_orientation: Optional[PaperOrientation] = PaperOrientation.PORTRAIT,
+            from_user: Optional[User] = None,
             include_appendices: Optional[bool] = False,
             include_qr_code: Optional[bool] = False,
+            **kwargs
     ) -> None:
         """
         Share the PDF of the `Activity` through email.
@@ -970,6 +982,8 @@ class Activity(TreeObject, TagsMixin, Activity2):
                                - portrait (default): portrait orientation
                                - landscape: landscape orientation
         :type paper_size: basestring (see :class:`enums.PaperOrientation`)
+        :param from_user: User that shared the PDF (optional)
+        :type from_user: User object
         :param include_appendices: True if the PDF should contain appendices, False (default) if otherwise.
         :type include_appendices: bool
         :param include_qr_code: True if the PDF should include a QR-code, False (default) if otherwise.
@@ -1000,9 +1014,82 @@ class Activity(TreeObject, TagsMixin, Activity2):
             includeqr=check_type(include_qr_code, bool, "include_qr_code"),
         )
 
+        if from_user:
+            check_user(from_user, User, 'from_user')
+            params.update(
+                from_user=from_user.id
+            )
+
         url = self._client._build_url('notification_share_activity_pdf')
 
         response = self._client._request('POST', url, data=params)
 
         if response.status_code not in (requests.codes.created, requests.codes.accepted):  # pragma: no cover
             raise APIError("Could not share the link to Activity {}".format(self), response=response)
+
+    #
+    # Context Methods
+    #
+    def context(self, *args, **kwargs) -> 'Context':
+        """
+        Retrieve a context object associated to this activity and scope.
+
+        See :class:`pykechain.Client.context` for available parameters.
+
+        .. versionadded:: 3.12
+
+        :return: a Context object
+        """
+        return self._client.context(*args, scope=self.scope, activity=self, **kwargs)
+
+    def contexts(self, *args, **kwargs) -> List['Context']:
+        """
+        Retrieve context objects t associated to this activity and scope.
+
+        See :class:`pykechain.Client.contexts` for available parameters.
+
+        .. versionadded:: 3.12
+
+        :return: a list of Context objects
+        """
+        return self._client.contexts(scope=self.scope, activity=self, **kwargs)
+
+    def create_context(self, *args, **kwargs) -> 'Context':
+        """
+        Create a new Context object of a ContextType in a scope and associated it to this activity.
+
+        See :class:`pykechain.Client.create_context` for available parameters.
+
+        .. versionadded:: 3.12
+
+        :return: a Context object
+        """
+        return self._client.create_context(scope=self.scope, actitivities=[self], **kwargs)
+
+    def link_context(self, context: 'Context') -> None:
+        """
+        Link the current activity to an existing Context.
+
+        If you want to link multiple activities at once, use the `Context.link_activities()` method.
+
+        :param context: A Context object to link the current activity to.
+        :raises IllegalArgumentError: When the context is not a Context object.
+        """
+        if not context.__class__.__name__ == 'Context':
+            raise IllegalArgumentError("`context` should be a proper Context object. Got: {}".format(context))
+        context.link_activities(activities=[self])
+        self.refresh()
+
+    def unlink_context(self, context: 'Context') -> None:
+        """
+        Link the current activity to an existing Context.
+
+        If you want to unlink multiple activities at once, use the `Context.unlink_activities()` method.
+
+        :param context: A Context object to unlink the current activity from.
+        :raises IllegalArgumentError: When the context is not a Context object.
+        """
+        if not context.__class__.__name__ == 'Context':
+            raise IllegalArgumentError("`context` should be a proper Context object. Got: {}".format(context))
+        context.unlink_activities(activities=[self])
+        self.refresh()
