@@ -5,14 +5,13 @@ import requests
 from pykechain.defaults import API_EXTRA_PARAMS, PARTS_BATCH_LIMIT
 from pykechain.enums import Category, Multiplicity, Classification, PropertyType
 from pykechain.exceptions import APIError, IllegalArgumentError, NotFoundError, MultipleFoundError
-from pykechain.models.part2 import Part2
 from pykechain.models.input_checks import check_text, check_type, check_list_of_base, check_list_of_dicts
 from pykechain.models.property import Property
 from pykechain.models.tree_traversal import TreeObject
 from pykechain.utils import is_uuid, find, Empty, clean_empty_values, empty
 
 
-class Part(TreeObject, Part2):
+class Part(TreeObject):
     """A virtual object representing a KE-chain part.
 
     :ivar id: UUID of the part
@@ -79,18 +78,18 @@ class Part(TreeObject, Part2):
         # we need to run the init of 'Base' instead of 'Part' as we do not need the instantiation of properties
         super().__init__(json, **kwargs)
 
-        self.ref = json.get('ref')  # type: Text
-        self.model_id = json.get("model_id")  # type: Text
-        self.category = json.get('category')  # type: Category
-        self.description = json.get('description')  # type: Text
-        self.multiplicity = json.get('multiplicity')  # type: Text
-        self.classification = json.get('classification')  # type: Classification
+        self.ref: Text = json.get('ref')
+        self.model_id: Text = json.get("model_id")
+        self.category: Category = json.get('category')
+        self.description: Text = json.get('description')
+        self.multiplicity: Text = json.get('multiplicity')
+        self.classification: Classification = json.get('classification')
 
-        sorted_properties = sorted(json['properties'], key=lambda p: p.get('order', 0))  # type: List[Dict]
-        self.properties = [Property.create(p, client=self._client) for p in sorted_properties]  # type: List[Property]
+        sorted_properties: List[Dict] = sorted(json['properties'], key=lambda p: p.get('order', 0))
+        self.properties: List[Property] = [Property.create(p, client=self._client) for p in sorted_properties]
 
-        proxy_data = json.get('proxy_source_id_name', dict())  # type: Optional[Dict]
-        self._proxy_model_id = proxy_data.get('id') if proxy_data else None  # type: Optional[Text]
+        proxy_data: Optional[Dict] = json.get('proxy_source_id_name', dict())
+        self._proxy_model_id: Optional[Text] = proxy_data.get('id') if proxy_data else None
 
     def __call__(self, *args, **kwargs) -> 'Part':
         """Short-hand version of the `child` method."""
@@ -483,17 +482,17 @@ class Part(TreeObject, Part2):
 
         >>> front_fork = project.part('Front Fork')
         >>> front_fork.edit(name='Front Fork - updated')
-        >>> front_fork.edit(name='Front Fork cruizer', description='With my ragtop down so my hair can blow' )
+        >>> front_fork.edit(name='Front Fork cruizer',description='With my ragtop down so my hair can blow')
 
         for changing a model:
 
         >>> front_fork = project.model('Front Fork')
-        >>> front_fork.edit(name='Front Fork basemodel', description='Some description here')
+        >>> front_fork.edit(name='Front Fork basemodel',description='Some description here')
 
         Not mentioning an input parameter in the function will leave it unchanged. Setting a parameter as None will
         clear its value (where that is possible). The example below will clear the description and edit the name.
 
-        >>> front_fork.edit(name="Front spoon", description=None)
+        >>> front_fork.edit(name="Front spoon",description=None)
 
         """
         update_dict = {
@@ -713,7 +712,7 @@ class Part(TreeObject, Part2):
         parsed_dict = dict()
 
         for prop_name_or_id, property_value in update_dict.items():
-            property_to_update = part.property(prop_name_or_id)  # type: Property
+            property_to_update: Property = part.property(prop_name_or_id)
 
             updated_p = {
                 "value": property_to_update.serialize_value(property_value),
@@ -811,7 +810,7 @@ class Part(TreeObject, Part2):
         if response.status_code != requests.codes.created:  # pragma: no cover
             raise APIError("Could not add to Part {}".format(self), response=response)
 
-        new_part_instance = Part(response.json()['results'][0], client=self._client)  # type: Part
+        new_part_instance: Part = Part(response.json()['results'][0], client=self._client)
 
         # ensure that cached children are updated
         if self._cached_children is not None:
@@ -914,11 +913,11 @@ class Part(TreeObject, Part2):
         return copied_part
 
     def move(
-        self,
-        target_parent: 'Part',
-        name: Optional[Text] = None,
-        include_children: bool = True,
-        include_instances: bool = True,
+            self,
+            target_parent: 'Part',
+            name: Optional[Text] = None,
+            include_children: bool = True,
+            include_instances: bool = True,
     ) -> 'Part':
         """
         Move the `Part` to target parent, both of them the same category.
