@@ -1,11 +1,13 @@
 import datetime
+import urllib
 import warnings
 from abc import abstractmethod
 from typing import Text, Union, Any, Dict, List, Optional
 
 from pykechain.enums import FilterType, Category, PropertyType, ScopeStatus
 from pykechain.exceptions import IllegalArgumentError, NotFoundError
-from pykechain.models.input_checks import check_base, check_enum, check_type, check_text, check_datetime
+from pykechain.models.input_checks import check_base, check_enum, check_type, check_text, \
+    check_datetime
 from pykechain.models.widgets.enums import MetaWidget
 
 
@@ -14,7 +16,8 @@ class BaseFilter(object):
 
     def __eq__(self, other):
         if isinstance(other, self.__class__):
-            return self.__class__.write_options(filters=[self]) == self.__class__.write_options(filters=[other])
+            return self.__class__.write_options(filters=[self]) == self.__class__.write_options(
+                filters=[other])
         else:
             return False
 
@@ -73,7 +76,12 @@ class PropertyValueFilter(BaseFilter):
 
     def format(self) -> Text:
         """Format PropertyValueFilter as a string."""
-        value = str(self.value).lower() if isinstance(self.value, bool) else self.value
+        if isinstance(self.value, str):
+            value = urllib.parse.quote(self.value)
+        elif isinstance(self.value, bool):
+            value = str(self.value).lower()
+        else:
+            value = self.value
         return "{}:{}:{}".format(self.id, value, self.type)
 
     def validate(self, part_model: 'Part') -> None:
@@ -86,20 +94,59 @@ class PropertyValueFilter(BaseFilter):
         from pykechain.models import Part
 
         check_base(part_model, Part, "part_model")
-
         try:
             prop = part_model.property(self.id)
         except NotFoundError:
             raise IllegalArgumentError(
-                "Property value filters can only be set on properties belonging to the selected Part model.")
+                "Property value filters can only be set on properties belonging to the selected "
+                "Part model.")
 
         if prop.category != Category.MODEL:
             raise IllegalArgumentError(
-                'Property value filters can only be set on Property models, received "{}".'.format(prop))
+                'Property value filters can only be set on Property models, received "{}".'.format(
+                    prop))
         else:
-            if prop.type == PropertyType.BOOLEAN_VALUE and self.type != FilterType.EXACT:
-                warnings.warn("A PropertyValueFilter on a boolean property should use filter type `{}`".format(
-                    FilterType.EXACT), Warning)
+            property_type = prop.type
+            if property_type in (PropertyType.BOOLEAN_VALUE,
+                                 PropertyType.REFERENCES_VALUE,
+                                 PropertyType.ACTIVITY_REFERENCES_VALUE
+                                 ) and self.type != FilterType.EXACT:
+                warnings.warn("A PropertyValueFilter on a `{}` property should use "
+                              "filter type `{}`, not `{}`".format(property_type, FilterType.EXACT,
+                                                                  self.type), Warning)
+            elif property_type in (PropertyType.TEXT_VALUE,
+                                   PropertyType.CHAR_VALUE,
+                                   PropertyType.LINK_VALUE,
+                                   PropertyType.SINGLE_SELECT_VALUE,
+                                   PropertyType.USER_REFERENCES_VALUE,
+                                   PropertyType.SCOPE_REFERENCES_VALUE,
+                                   ) and self.type != FilterType.CONTAINS:
+                warnings.warn("A PropertyValueFilter on a `{}` property should use "
+                              "filter type `{}`, not `{}`".format(property_type,
+                                                                  FilterType.CONTAINS,
+                                                                  self.type), Warning)
+            elif property_type in (PropertyType.INT_VALUE,
+                                   PropertyType.FLOAT_VALUE,
+                                   PropertyType.DATE_VALUE,
+                                   PropertyType.DATETIME_VALUE
+                                   ) and self.type not in (
+                FilterType.LOWER_THAN_EQUAL,
+                FilterType.GREATER_THAN_EQUAL
+            ):
+                warnings.warn("A PropertyValueFilter on a `{}` property should use "
+                              "filter type `{}` or `{}`, not `{}`".
+                              format(property_type,
+                                     FilterType.LOWER_THAN_EQUAL,
+                                     FilterType.GREATER_THAN_EQUAL,
+                                     self.type), Warning)
+            elif property_type in (PropertyType.MULTI_SELECT_VALUE,
+                                   ) and self.type != FilterType.CONTAINS_SET:
+                warnings.warn("A PropertyValueFilter on a `{}` property should use "
+                              "filter type `{}`, not `{}`".format(property_type,
+                                                                  FilterType.CONTAINS_SET,
+                                                                  self.type), Warning)
+            else:
+                pass
 
     @classmethod
     def parse_options(cls, options: Dict) -> List['PropertyValueFilter']:
@@ -119,7 +166,7 @@ class PropertyValueFilter(BaseFilter):
         for pf_string in prefilter_string_list:
             prefilter_raw = pf_string.split(":")
 
-            if len(prefilter_raw) == 1:   # FIXME encoding problem KE-chain
+            if len(prefilter_raw) == 1:  # FIXME encoding problem KE-chain
                 prefilter_raw = pf_string.split("%3A")
 
             prefilters.append(PropertyValueFilter(*prefilter_raw))
@@ -166,18 +213,18 @@ class ScopeFilter(BaseFilter):
     ]
 
     def __init__(
-            self,
-            tag: Optional[Text] = None,
-            status: Optional[ScopeStatus] = None,
-            name: Optional[Text] = None,
-            team: Optional[Union[Text, 'Team']] = None,
-            due_date_gte: Optional[datetime.datetime] = None,
-            due_date_lte: Optional[datetime.datetime] = None,
-            start_date_gte: Optional[datetime.datetime] = None,
-            start_date_lte: Optional[datetime.datetime] = None,
-            progress_gte: Optional[float] = None,
-            progress_lte: Optional[float] = None,
-            **kwargs
+        self,
+        tag: Optional[Text] = None,
+        status: Optional[ScopeStatus] = None,
+        name: Optional[Text] = None,
+        team: Optional[Union[Text, 'Team']] = None,
+        due_date_gte: Optional[datetime.datetime] = None,
+        due_date_lte: Optional[datetime.datetime] = None,
+        start_date_gte: Optional[datetime.datetime] = None,
+        start_date_lte: Optional[datetime.datetime] = None,
+        progress_gte: Optional[float] = None,
+        progress_lte: Optional[float] = None,
+        **kwargs
     ):
         """Create a ScopeFilter object."""
         from pykechain.models import Team
