@@ -428,6 +428,7 @@ class TestWidgetManagerInActivity(TestBetamax):
         widget = self.wm.add_filteredgrid_widget(
             part_model=part_model,
             parent_instance=parent_instance,
+            custom_height=500,
             edit=True,
             sort_name=True,
             emphasize_edit=True,
@@ -459,7 +460,8 @@ class TestWidgetManagerInActivity(TestBetamax):
 
         widget1 = self.wm.add_signature_widget(attachment_property=picture, title="Yes, my precious",
                                                custom_undo_button_text="Remove za widget",
-                                               custom_button_text="Sign za widget")
+                                               custom_button_text="Sign za widget, plz",
+                                               show_name_and_date=False)
         widget2 = self.wm.add_signature_widget(attachment_property=picture, title=False,
                                                custom_undo_button_text=False,
                                                custom_button_text=False)
